@@ -45,6 +45,8 @@ class SideTabs(HilightingWidget):
 
         if (need_prepare and self.__tabs):
             self.__prepare_tabs()
+            self.select_tab(self.__current_tab)
+
 
 
     def render_this(self):
@@ -63,10 +65,7 @@ class SideTabs(HilightingWidget):
             offset += pmap.get_size()[1]
         #end for
 
-        if (self.__current_tab == -1):
-            self.select_tab(0)
-            
-        
+
     def __on_click(self, px, py):
         
         h, w = self.get_size()
@@ -104,7 +103,8 @@ class SideTabs(HilightingWidget):
             w, h = self.__tab_pmaps[0].get_size()
             self.__tab_size = (w, h)
             self.set_hilighting_box(
-                  pixbuftools.make_frame(theme.mb_selection_frame, w, h, True))
+                  pixbuftools.make_frame(theme.mb_selection_frame, w, h, True,
+                     pixbuftools.LEFT | pixbuftools.BOTTOM | pixbuftools.TOP))
         #end if
         self.__is_prepared = True
 
@@ -144,12 +144,26 @@ class SideTabs(HilightingWidget):
         Selects the given tab.
         """
     
-        tab_w, tab_h = self.__tab_size
-        cb, args = self.__tab_callbacks[idx]
-        self.move_hilighting_box(0, idx * tab_h)
-        try:
-            cb(*args)
-        except:
-            pass
-        self.__current_tab = idx
+        if (idx != self.__current_tab):
+            tab_w, tab_h = self.__tab_size
+            cb, args = self.__tab_callbacks[idx]
+            self.move_hilighting_box(0, idx * tab_h)
+            try:
+                cb(*args)
+            except:
+                pass
+            self.__current_tab = idx
+        #end if
+
+
+    def switch_tab(self):
+        """
+        Switches tabs.
+        @since: 0.96.5
+        """
+        
+        idx = self.__current_tab + 1
+        if (idx == len(self.__tabs)):
+            idx = 0
+        self.select_tab(idx)
 
